Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.
func SetVersionInfo ¶ added in v0.1.4
func SetVersionInfo(version, commit, date string)
SetVersionInfo wires release metadata from main into the cmd package. Called once from main.main before Execute.
Types ¶
This section is empty.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.